@@ -1,17 +1,15 @@
 # from Pyramid
 
-class reify(object):
 
-    """ Put the result of a method which uses this (non-data)
+class reify(object):
+    """Put the result of a method which uses this (non-data)
     descriptor decorator in the instance dict after the first call,
-    effectively replacing the decorator with an instance variable."""
+    effectively replacing the decorator with an instance variable.
+    """
 
     def __init__(self, wrapped):
         self.wrapped = wrapped
-        try:
-            self.__doc__ = wrapped.__doc__
-        except: # pragma: no cover
-            pass
+        self.__doc__ = wrapped.__doc__
 
     def __get__(self, inst, objtype=None):
         if inst is None:
@@ -19,4 +17,3 @@ class reify(object):
         val = self.wrapped(inst)
         setattr(inst, self.wrapped.__name__, val)
         return val
-
